@@ -1,6 +1,6 @@
 package Reflex::Callbacks;
 BEGIN {
-  $Reflex::Callbacks::VERSION = '0.056';
+  $Reflex::Callbacks::VERSION = '0.060';
 }
 
 # Reflex::Callbacks is a callback manager.  It encapsulates the
@@ -191,7 +191,7 @@ Reflex::Callbacks - Convenience functions for creating and using callbacks
 
 =head1 VERSION
 
-version 0.056
+version 0.060
 
 =head1 SYNOPSIS
 
@@ -375,7 +375,7 @@ deliver events to the callback.
 cb_coderef() neither takes nor returns an event name.  As such, the
 Reflex::Base parameter name must be supplied outside cb_coderef().
 
-	my $timer = Reflex::Timer->new(
+	my $timer = Reflex::Interval->new(
 		interval    => 1,
 		auto_repeat => 1,
 		on_tick     => cb_coderef { print "tick!\n" },
